Package: geigen
Version: 2.3
Title: Calculate Generalized Eigenvalues, the Generalized Schur
        Decomposition and the Generalized Singular Value Decomposition
        of a Matrix Pair with Lapack
Date: 2019-05-29
Depends: R (>= 3.5.0)
Authors@R: c(person("Berend","Hasselman",role=c("cre","aut"),email="bhh@xs4all.nl"),
            person("Lapack authors", role=c("aut","cph")))
Description: Functions to compute generalized eigenvalues and eigenvectors,
             the generalized Schur decomposition and
             the generalized Singular Value Decomposition of a matrix pair,
             using Lapack routines.
License: GPL (>= 2)
Copyright: see inst/COPYRIGHTS for the files in src/.
NeedsCompilation: yes
Packaged: 2019-05-30 06:10:31 UTC; berendhasselman
Author: Berend Hasselman [cre, aut],
  Lapack authors [aut, cph]
Maintainer: Berend Hasselman <bhh@xs4all.nl>
Repository: CRAN
Date/Publication: 2019-05-30 09:30:03 UTC
Built: R 3.6.1; x86_64-w64-mingw32; 2019-08-20 16:27:02 UTC; windows
Archs: x64
